import { Project } from '..';
import { Component } from '../component';
import { Task } from '../tasks';
/**
 * (experimental) Common options for `LambdaFunction`.
 *
 * Applies to all functions in
 * auto-discovery.
 *
 * @experimental
 */
export interface LambdaFunctionCommonOptions {
    /**
     * (experimental) The node.js version to target.
     *
     * @default Runtime.NODEJS_14_X
     * @experimental
     */
    readonly runtime?: LambdaRuntime;
    /**
     * (experimental) Names of modules which should not be included in the bundle.
     *
     * @default - by default, the "aws-sdk" module will be excluded from the
     * bundle. Note that if you use this option you will need to add "aws-sdk"
     * explicitly.
     * @experimental
     */
    readonly externals?: string[];
}
/**
 * (experimental) Options for `Function`.
 *
 * @experimental
 */
export interface LambdaFunctionOptions extends LambdaFunctionCommonOptions {
    /**
     * (experimental) A path from the project root directory to a TypeScript file which contains the AWS Lambda handler entrypoint (exports a `handler` function).
     *
     * @experimental
     */
    readonly entrypoint: string;
    /**
     * (experimental) The name of the generated TypeScript source file.
     *
     * @default - The name of the entrypoint file, with the `-function.ts` suffix
     * instead of `.lambda.ts`.
     * @experimental
     */
    readonly constructFile?: string;
    /**
     * (experimental) The name of the generated `lambda.Function` subclass.
     *
     * @default - A pascal cased version of the name of the entrypoint file, with
     * the extension `Function` (e.g. `ResizeImageFunction`).
     * @experimental
     */
    readonly constructName?: string;
    /**
     * (experimental) Project source directory tree (where .ts files live).
     *
     * @experimental
     */
    readonly srcdir: string;
    /**
     * (experimental) JavaScript output directory (where .js files go).
     *
     * @experimental
     */
    readonly libdir: string;
}
/**
 * (experimental) Generates a pre-bundled AWS Lambda function construct from handler code.
 *
 * To use this, create an AWS Lambda handler file under your source tree with
 * the `.lambda.ts` extension and add a `LambdaFunction` component to your
 * typescript project pointing to this entrypoint.
 *
 * This will add a task to your "compile" step which will use `esbuild` to
 * bundle the handler code into the build directory. It will also generate a
 * file `src/foo-function.ts` with a custom AWS construct called `FooFunction`
 * which extends `@aws-cdk/aws-lambda.Function` which is bound to the bundled
 * handle through an asset.
 *
 * @experimental
 * @example
 *
 * new LambdaFunction(myProject, {
 *   entrypoint: 'src/foo.lambda.ts',
 *   srcdir: myProject.srcdir,
 *   libdir: myProject.libdir,
 * });
 */
export declare class LambdaFunction extends Component {
    /**
     * (experimental) The bundle task for this function.
     *
     * @experimental
     */
    readonly bundleTask: Task;
    /**
     * (experimental) Defines a pre-bundled AWS Lambda function construct from handler code.
     *
     * @param project The project to use.
     * @param options Options.
     * @experimental
     */
    constructor(project: Project, options: LambdaFunctionOptions);
}
/**
 * (experimental) The runtime for the AWS Lambda function.
 *
 * @experimental
 */
export declare class LambdaRuntime {
    /**
     * The aws-lambda.Runtime member name to use.
     */
    readonly functionRuntime: string;
    /**
     * The esbuild setting to use.
     */
    readonly esbuildTarget: string;
    /**
     * (experimental) Node.js 10.x.
     *
     * @experimental
     */
    static readonly NODEJS_10_X: LambdaRuntime;
    /**
     * (experimental) Node.js 12.x.
     *
     * @experimental
     */
    static readonly NODEJS_12_X: LambdaRuntime;
    /**
     * (experimental) Node.js 14.x.
     *
     * @experimental
     */
    static readonly NODEJS_14_X: LambdaRuntime;
    /**
     * @experimental
     */
    readonly esbuildPlatform = "node";
    private constructor();
}
